@@ -26,28 +26,20 @@ DEFAULT_BASE_TAGS = {
     'rhel': '7',
     'oraclelinux': '7-slim',
     'debian': 'stretch-backports',
-    'ubuntu': '16.04',
+    'ubuntu': '18.04',
 }
 DISTRO_RELEASE = {
     'centos': '7',
     'rhel': '7',
     'oraclelinux': '7',
     'debian': 'stretch-backports',
-    'ubuntu': '16.04',
+    'ubuntu': '18.04',
 }
 
 # This is noarch repository so we will use it on all architectures
 DELOREAN = \
     "https://trunk.rdoproject.org/centos7/current-passed-ci/delorean.repo"
-
-# TODO(hrw): with move to Pike+1 we need to make sure that aarch64 repo
-#            gets updated (docker/base/aarch64-cbs.repo file)
-#            there is ongoing work to sort that out
-DELOREAN_DEPS = {
-    'x86_64': "https://trunk.rdoproject.org/centos7/delorean-deps.repo",
-    'aarch64': "",
-    'ppc64le': "https://trunk.rdoproject.org/centos7/delorean-deps.repo"
-}
+DELOREAN_DEPS = "https://trunk.rdoproject.org/centos7/delorean-deps.repo"
 
 INSTALL_TYPE_CHOICES = ['binary', 'source', 'rdo', 'rhos']
 
@@ -66,6 +58,7 @@ _PROFILE_OPTS = [
                     'keepalived',
                     'kibana',
                     'kolla-toolbox',
+                    'logstash',
                     'mariadb',
                     'memcached',
                     'mongodb',
@@ -77,6 +70,7 @@ _PROFILE_OPTS = [
                     'redis',
                     'rsyslog',
                     'skydive',
+                    'storm',
                     'tgtd',
                 ],
                 help='Infra images'),
@@ -204,6 +198,8 @@ _CLI_OPTS = [
                 help='Show all available images (filtering supported)'),
     cfg.StrOpt('namespace', short='n', default='kolla',
                help='The Docker namespace name'),
+    cfg.StrOpt('network_mode', default=None,
+               help='The network mode for Docker build. Example: host'),
     cfg.BoolOpt('cache', default=True,
                 help='Use the Docker cache when building'),
     cfg.MultiOpt('profile', types.String(), short='p',
@@ -284,51 +280,51 @@ SOURCES = {
     'openstack-base': {
         'type': 'url',
         'location': ('$tarballs_base/requirements/'
-                     'requirements-stable-queens.tar.gz')},
+                     'requirements-stable-rocky.tar.gz')},
     'almanach-base': {
         'type': 'url',
         'location': ('$tarballs_base/almanach/'
-                     'almanach-stable-queens.tar.gz')},
+                     'almanach-master.tar.gz')},
     'aodh-base': {
         'type': 'url',
         'location': ('$tarballs_base/aodh/'
-                     'aodh-6.0.1.tar.gz')},
+                     'aodh-7.0.0.tar.gz')},
     'barbican-base': {
         'type': 'url',
         'location': ('$tarballs_base/barbican/'
-                     'barbican-6.0.1.tar.gz')},
+                     'barbican-7.0.0.tar.gz')},
     'bifrost-base': {
         'type': 'url',
         'location': ('$tarballs_base/bifrost/'
-                     'bifrost-5.0.3.tar.gz')},
+                     'bifrost-5.1.0.tar.gz')},
     'blazar-base': {
         'type': 'url',
         'location': ('$tarballs_base/blazar/'
-                     'blazar-1.0.0.tar.gz')},
+                     'blazar-2.0.0.tar.gz')},
     'ceilometer-base': {
         'type': 'url',
         'location': ('$tarballs_base/ceilometer/'
-                     'ceilometer-10.0.1.tar.gz')},
+                     'ceilometer-11.0.0.tar.gz')},
     'ceilometer-base-plugin-panko': {
         'type': 'url',
         'location': ('$tarballs_base/panko/'
-                     'panko-4.0.2.tar.gz')},
+                     'panko-5.0.0.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/cinder/'
-                     'cinder-12.0.8.tar.gz')},
+                     'cinder-13.0.0.tar.gz')},
     'congress-base': {
         'type': 'url',
         'location': ('$tarballs_base/congress/'
-                     'openstack-congress-7.0.2.tar.gz')},
+                     'congress-8.0.0.tar.gz')},
     'cloudkitty-base': {
         'type': 'url',
         'location': ('$tarballs_base/cloudkitty/'
-                     'cloudkitty-7.0.0.tar.gz')},
+                     'cloudkitty-8.0.0.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('$tarballs_base/designate/'
-                     'designate-6.0.1.tar.gz')},
+                     'designate-7.0.0.tar.gz')},
     'dragonflow-base': {
         'type': 'url',
         'location': ('$tarballs_base/dragonflow/'
@@ -336,280 +332,313 @@ SOURCES = {
     'ec2-api': {
         'type': 'url',
         'location': ('$tarballs_base/ec2-api/'
-                     'ec2-api-6.0.0.tar.gz')},
+                     'ec2-api-7.1.0.tar.gz')},
     'freezer-api': {
         'type': 'url',
         'location': ('$tarballs_base/freezer-api/'
-                     'freezer-api-6.0.0.tar.gz')},
+                     'freezer-api-master.tar.gz')},
     'freezer-base': {
         'type': 'url',
         'location': ('$tarballs_base/freezer/'
-                     'freezer-6.0.0.tar.gz')},
+                     'freezer-master.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('$tarballs_base/glance/'
-                     'glance-16.0.1.tar.gz')},
+                     'glance-17.0.0.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
-        'reference': '4.2.0',
+        'reference': '4.3.0',
         'location': ('https://github.com/gnocchixyz/'
                      'gnocchi.git')},
     'heat-base': {
         'type': 'url',
         'location': ('$tarballs_base/heat/'
-                     'heat-10.0.2.tar.gz')},
+                     'heat-11.0.0.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('$tarballs_base/horizon/'
-                     'horizon-13.0.2.tar.gz')},
+                     'horizon-14.0.0.tar.gz')},
+    'horizon-plugin-blazar-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/blazar-dashboard/'
+                     'blazar-dashboard-1.2.0.tar.gz')},
+    'horizon-plugin-congress-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/congress-dashboard/'
+                     'congress-dashboard-3.0.0.tar.gz')},
     'horizon-plugin-cloudkitty-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/cloudkitty-dashboard/'
-                     'cloudkitty-dashboard-7.0.0.tar.gz')},
+                     'cloudkitty-dashboard-8.0.0.tar.gz')},
     'horizon-plugin-designate-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/designate-dashboard/'
-                     'designate-dashboard-6.0.1.tar.gz')},
+                     'designate-dashboard-7.0.0.tar.gz')},
     'horizon-plugin-fwaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-fwaas-dashboard/'
-                     'neutron-fwaas-dashboard-1.3.0.tar.gz')},
+                     'neutron-fwaas-dashboard-1.5.0.tar.gz')},
     'horizon-plugin-freezer-web-ui': {
         'type': 'url',
         'location': ('$tarballs_base/freezer-web-ui/'
-                     'freezer-web-ui-6.0.0.tar.gz')},
+                     'freezer-web-ui-master.tar.gz')},
     'horizon-plugin-heat-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/heat-dashboard/'
-                     'heat-dashboard-1.0.3.tar.gz')},
+                     'heat-dashboard-1.4.0.tar.gz')},
     'horizon-plugin-ironic-ui': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-ui/'
-                     'ironic-ui-3.1.2.tar.gz')},
+                     'ironic-ui-3.3.0.tar.gz')},
     'horizon-plugin-karbor-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/karbor-dashboard/'
-                     'karbor-dashboard-1.0.0.tar.gz')},
+                     'karbor-dashboard-1.1.0.tar.gz')},
     'horizon-plugin-magnum-ui': {
         'type': 'url',
         'location': ('$tarballs_base/magnum-ui/'
-                     'magnum-ui-4.0.1.tar.gz')},
+                     'magnum-ui-5.0.1.tar.gz')},
     'horizon-plugin-manila-ui': {
         'type': 'url',
         'location': ('$tarballs_base/manila-ui/'
-                     'manila-ui-2.13.1.tar.gz')},
+                     'manila-ui-2.16.0.tar.gz')},
     'horizon-plugin-mistral-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/mistral-dashboard/'
-                     'mistral-dashboard-6.0.1.tar.gz')},
+                     'mistral-dashboard-7.0.1.tar.gz')},
     'horizon-plugin-monasca-ui': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-ui/'
-                     'monasca-ui-1.12.1.tar.gz')},
+                     'monasca-ui-1.14.0.tar.gz')},
     'horizon-plugin-murano-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/murano-dashboard/'
-                     'murano-dashboard-5.0.0.tar.gz')},
+                     'murano-dashboard-6.0.0.tar.gz')},
     'horizon-plugin-neutron-lbaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-lbaas-dashboard/'
-                     'neutron-lbaas-dashboard-4.0.0.tar.gz')},
+                     'neutron-lbaas-dashboard-5.0.0.tar.gz')},
+    'horizon-plugin-neutron-vpnaas-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/neutron-vpnaas-dashboard/'
+                     'neutron-vpnaas-dashboard-1.4.0.tar.gz')},
     'horizon-plugin-octavia-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/octavia-dashboard/'
-                     'octavia-dashboard-1.0.2.tar.gz')},
+                     'octavia-dashboard-2.0.0.tar.gz')},
     'horizon-plugin-sahara-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-dashboard/'
-                     'sahara-dashboard-8.0.1.tar.gz')},
+                     'sahara-dashboard-9.0.0.tar.gz')},
     'horizon-plugin-searchlight-ui': {
         'type': 'url',
         'location': ('$tarballs_base/searchlight-ui/'
-                     'searchlight-ui-4.0.0.tar.gz')},
+                     'searchlight-ui-master.tar.gz')},
     'horizon-plugin-senlin-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/senlin-dashboard/'
-                     'senlin-dashboard-0.8.0.tar.gz')},
+                     'senlin-dashboard-0.9.0.tar.gz')},
     'horizon-plugin-solum-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/solum-dashboard/'
-                     'solum-dashboard-2.3.0.tar.gz')},
+                     'solum-dashboard-2.5.0.tar.gz')},
     'horizon-plugin-tacker-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/tacker-horizon/'
-                     'tacker-horizon-0.11.0.tar.gz')},
+                     'tacker-horizon-0.12.0.tar.gz')},
     'horizon-plugin-trove-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/trove-dashboard/'
-                     'trove-dashboard-10.0.0.tar.gz')},
+                     'trove-dashboard-11.0.0.tar.gz')},
     'horizon-plugin-vitrage-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/vitrage-dashboard/'
-                     'vitrage-dashboard-1.4.2.tar.gz')},
+                     'vitrage-dashboard-1.6.1.tar.gz')},
     'horizon-plugin-watcher-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/watcher-dashboard/'
-                     'watcher-dashboard-1.8.0.tar.gz')},
+                     'watcher-dashboard-1.11.0.tar.gz')},
     'horizon-plugin-zaqar-ui': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar-ui/'
-                     'zaqar-ui-4.0.1.tar.gz')},
+                     'zaqar-ui-5.0.0.tar.gz')},
     'horizon-plugin-zun-ui': {
         'type': 'url',
         'location': ('$tarballs_base/zun-ui/'
-                     'zun-ui-1.0.0.tar.gz')},
+                     'zun-ui-2.0.0.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('$tarballs_base/ironic/'
-                     'ironic-10.1.9.tar.gz')},
+                     'ironic-11.1.0.tar.gz')},
     'ironic-inspector': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-inspector/'
-                     'ironic-inspector-7.2.4.tar.gz')},
+                     'ironic-inspector-8.0.0.tar.gz')},
     'karbor-base': {
         'type': 'url',
         'location': ('$tarballs_base/karbor/'
-                     'karbor-1.0.0.tar.gz')},
+                     'karbor-1.1.0.tar.gz')},
     'keystone-base': {
         'type': 'url',
         'location': ('$tarballs_base/keystone/'
-                     'keystone-13.0.2.tar.gz')},
+                     'keystone-14.0.0.tar.gz')},
     'kuryr-base': {
         'type': 'url',
         'location': ('$tarballs_base/kuryr/'
-                     'kuryr-lib-0.7.0.tar.gz')},
+                     'kuryr-lib-0.8.0.tar.gz')},
     'kuryr-libnetwork': {
         'type': 'url',
         'location': ('$tarballs_base/kuryr-libnetwork/'
-                     'kuryr-libnetwork-1.0.0.tar.gz')},
+                     'kuryr-libnetwork-2.0.0.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('$tarballs_base/magnum/'
-                     'magnum-6.3.0.tar.gz')},
+                     'magnum-7.0.1.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('$tarballs_base/manila/'
-                     'manila-6.3.1.tar.gz')},
+                     'manila-7.0.0.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('$tarballs_base/mistral/'
-                     'mistral-6.0.6.tar.gz')},
+                     'mistral-7.0.3.tar.gz')},
     'mistral-base-plugin-tacker': {
         'type': 'url',
         'location': ('$tarballs_base/tacker/'
-                     'tacker-0.9.0.tar.gz')},
+                     'tacker-0.10.0.tar.gz')},
+    'monasca-agent': {
+        'type': 'url',
+        'location': ('$tarballs_base/monasca-agent/'
+                     'monasca-agent-2.8.0.tar.gz')},
     'monasca-api': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-api/'
-                     'monasca-api-2.5.0.tar.gz')},
+                     'monasca-api-2.7.0.tar.gz')},
     'monasca-log-api': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-log-api/'
-                     'monasca-log-api-2.6.0.tar.gz')},
+                     'monasca-log-api-2.7.0.tar.gz')},
     'monasca-notification': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-notification/'
-                     'monasca-notification-1.13.0.tar.gz')},
+                     'monasca-notification-1.14.0.tar.gz')},
     'monasca-persister': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-persister/'
-                     'monasca-persister-1.10.1.tar.gz')},
+                     'monasca-persister-1.12.0.tar.gz')},
     'monasca-statsd': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-statsd/'
-                     'monasca-statsd-1.9.0.tar.gz')},
+                     'monasca-statsd-1.10.1.tar.gz')},
+    # FIXME(dszumski): Use openstack tar when infra is fixed
+    'monasca-thresh': {
+        'type': 'url',
+        'location': ('https://github.com/openstack/monasca-thresh/archive/'
+                     'master.tar.gz')},
+    'monasca-thresh-additions-monasca-common': {
+        'type': 'url',
+        'location': ('$tarballs_base/monasca-common/'
+                     'monasca-common-2.11.0.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('$tarballs_base/murano/'
-                     'murano-5.0.0.tar.gz')},
+                     'murano-6.0.0.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('$tarballs_base/neutron/'
-                     'neutron-12.1.0.tar.gz')},
+                     'neutron-13.0.1.tar.gz')},
     'neutron-base-plugin-neutron-fwaas': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-fwaas/'
-                     'neutron-fwaas-12.0.1.tar.gz')},
+                     'neutron-fwaas-13.0.0.tar.gz')},
     'neutron-base-plugin-networking-ansible': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ansible/'
-                     'networking-ansible-0.1.0.tar.gz')},
+                     'networking-ansible-1.0.4.tar.gz')},
     'neutron-base-plugin-networking-baremetal': {
         'type': 'url',
         'location': ('$tarballs_base/networking-baremetal/'
-                     'networking-baremetal-1.0.0.tar.gz')},
+                     'networking-baremetal-1.2.0.tar.gz')},
     'neutron-base-plugin-networking-generic-switch': {
         'type': 'url',
         'location': ('$tarballs_base/networking-generic-switch/'
-                     'networking-generic-switch-1.0.0.tar.gz')},
+                     'networking-generic-switch-1.2.0.tar.gz')},
     'neutron-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-6.0.0.tar.gz')},
+                     'networking-sfc-7.0.0.tar.gz')},
     'neutron-base-plugin-vmware-nsx': {
         'type': 'url',
         'location': ('$tarballs_base/vmware-nsx/'
-                     'vmware-nsx-12.0.1.tar.gz')},
+                     'vmware-nsx-13.0.0.tar.gz')},
     'neutron-base-plugin-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-vpnaas/'
-                     'neutron-vpnaas-12.0.1.tar.gz')},
+                     'neutron-vpnaas-13.0.0.tar.gz')},
     'neutron-bgp-dragent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-12.0.1.tar.gz')},
+                     'neutron-dynamic-routing-13.0.0.tar.gz')},
     'neutron-lbaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-lbaas/'
-                     'neutron-lbaas-12.0.0.tar.gz')},
+                     'neutron-lbaas-13.0.0.tar.gz')},
+    'neutron-server-opendaylight-plugin-ceilometer': {
+        'type': 'url',
+        'location': ('$tarballs_base/ceilometer/'
+                     'ceilometer-11.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-odl': {
         'type': 'url',
         'location': ('$tarballs_base/networking-odl/'
-                     'networking-odl-12.0.0.tar.gz')},
+                     'networking-odl-13.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-bgpvpn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-bgpvpn/'
-                     'networking-bgpvpn-8.0.1.tar.gz')},
+                     'networking-bgpvpn-9.0.2.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-l2gw': {
         'type': 'url',
         'location': ('$tarballs_base/networking-l2gw/'
-                     'networking-l2gw-12.0.1.tar.gz')},
+                     'networking-l2gw-13.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-6.0.0.tar.gz')},
+                     'networking-sfc-7.0.0.tar.gz')},
+    'neutron-server-plugin-networking-infoblox': {
+        'type': 'url',
+        'location': ('$tarballs_base/networking-infoblox/'
+                     'networking-infoblox-master.tar.gz')},
     'neutron-server-plugin-neutron-dynamic-routing': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-12.0.1.tar.gz')},
+                     'neutron-dynamic-routing-13.0.0.tar.gz')},
     'neutron-server-plugin-neutron-lbaas': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-lbaas/'
-                     'neutron-lbaas-12.0.0.tar.gz')},
+                     'neutron-lbaas-13.0.0.tar.gz')},
     'neutron-server-plugin-vmware-nsxlib': {
         'type': 'url',
         'location': ('$tarballs_base/vmware-nsxlib/'
-                     'vmware-nsxlib-12.0.1.tar.gz')},
+                     'vmware-nsxlib-13.0.1.tar.gz')},
     'neutron-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-vpnaas/'
-                     'neutron-vpnaas-12.0.1.tar.gz')},
+                     'neutron-vpnaas-13.0.0.tar.gz')},
     'neutron-server-ovn-plugin-networking-ovn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ovn/'
-                     'networking-ovn-4.0.3.tar.gz')},
+                     'networking-ovn-5.0.1.tar.gz')},
     'neutron-metadata-agent-ovn-plugin-networking-ovn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ovn/'
-                     'networking-ovn-4.0.3.tar.gz')},
+                     'networking-ovn-5.0.1.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('$tarballs_base/nova/'
-                     'nova-17.0.12.tar.gz')},
+                     'nova-18.0.2.tar.gz')},
     'nova-base-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/blazar-nova/'
-                     'blazar-nova-1.0.1.tar.gz')},
+                     'blazar-nova-1.1.1.tar.gz')},
     'nova-base-plugin-mksproxy': {
         'type': 'url',
         'location': ('$tarballs_base/nova-mksproxy/'
@@ -617,89 +646,167 @@ SOURCES = {
     'novajoin-base': {
         'type': 'url',
         'location': ('$tarballs_base/novajoin/'
-                     'novajoin-1.0.18.tar.gz')},
+                     'novajoin-1.0.19.tar.gz')},
     'octavia-base': {
         'type': 'url',
         'location': ('$tarballs_base/octavia/'
-                     'octavia-2.1.1.tar.gz')},
-    'opendaylight': {
-        'type': 'url',
-        'location': ('https://nexus.opendaylight.org/content/'
-                     'repositories/opendaylight.release/org/opendaylight/'
-                     'integration/distribution-karaf/0.6.2-Carbon/'
-                     'distribution-karaf-0.6.2-Carbon.tar.gz')},
+                     'octavia-3.0.1.tar.gz')},
     'panko-base': {
         'type': 'url',
         'location': ('$tarballs_base/panko/'
-                     'panko-4.0.2.tar.gz')},
+                     'panko-5.0.0.tar.gz')},
     'tempest-plugin-tempest-conf': {
         'type': 'url',
         'location': ('$tarballs_base/python-tempestconf/'
-                     'python-tempestconf-1.1.4.tar.gz')},
+                     'python-tempestconf-2.0.0.tar.gz')},
+    'tempest-plugin-barbican': {
+        'type': 'url',
+        'location': ('$tarballs_base/barbican-tempest-plugin/'
+                     'barbican_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-blazar': {
+        'type': 'url',
+        'location': ('$tarballs_base/blazar-tempest-plugin/'
+                     'blazar_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-cinder': {
+        'type': 'url',
+        'location': ('$tarballs_base/cinder-tempest-plugin/'
+                     'cinder_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-congress': {
+        'type': 'url',
+        'location': ('$tarballs_base/congress-tempest-plugin/'
+                     'congress-tempest-plugin-0.1.0.tar.gz')},
+    'tempest-plugin-ec2api': {
+        'type': 'url',
+        'location': ('$tarballs_base/ec2api-tempest-plugin/'
+                     'ec2api-tempest-plugin-0.1.0.tar.gz')},
+    'tempest-plugin-heat': {
+        'type': 'url',
+        'location': ('$tarballs_base/heat-tempest-plugin/'
+                     'heat-tempest-plugin-0.2.0.tar.gz')},
+    'tempest-plugin-ironic': {
+        'type': 'url',
+        'location': ('$tarballs_base/ironic-tempest-plugin/'
+                     'ironic-tempest-plugin-1.2.0.tar.gz')},
+    'tempest-plugin-keystone': {
+        'type': 'url',
+        'location': ('$tarballs_base/keystone-tempest-plugin/'
+                     'keystone_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-magnum': {
+        'type': 'url',
+        'location': ('$tarballs_base/magnum-tempest-plugin/'
+                     'magnum_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-manila': {
+        'type': 'url',
+        'location': ('$tarballs_base/manila-tempest-plugin/'
+                     'manila-tempest-plugin-0.1.0.tar.gz')},
+    'tempest-plugin-mistral': {
+        'type': 'url',
+        'location': ('$tarballs_base/mistral-tempest-plugin/'
+                     'mistral_tempest_tests-0.1.0.tar.gz')},
+    'tempest-plugin-monasca': {
+        'type': 'url',
+        'location': ('$tarballs_base/monasca-tempest-plugin/'
+                     'monasca-tempest-plugin-0.2.0.tar.gz')},
+    'tempest-plugin-murano': {
+        'type': 'url',
+        'location': ('$tarballs_base/murano-tempest-plugin/'
+                     'murano-tempest-plugin-0.1.0.tar.gz')},
+    'tempest-plugin-neutron': {
+        'type': 'url',
+        'location': ('$tarballs_base/neutron-tempest-plugin/'
+                     'neutron_tempest_plugin-0.2.0.tar.gz')},
+    'tempest-plugin-patrole': {
+        'type': 'url',
+        'location': ('$tarballs_base/patrole/'
+                     'patrole-0.4.0.tar.gz')},
+    'tempest-plugin-telemetry': {
+        'type': 'url',
+        'location': ('$tarballs_base/telemetry-tempest-plugin/'
+                     'telemetry_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-tripleo-common': {
+        'type': 'url',
+        'location': ('$tarballs_base/tripleo-common-tempest-plugin/'
+                     'tripleo-common-tempest-plugin-master.tar.gz')},
+    'tempest-plugin-trove': {
+        'type': 'url',
+        'location': ('$tarballs_base/trove-tempest-plugin/'
+                     'trove_tempest_plugin-0.1.0.tar.gz')},
+    'tempest-plugin-vitrage': {
+        'type': 'url',
+        'location': ('$tarballs_base/vitrage-tempest-plugin/'
+                     'vitrage-tempest-plugin-1.1.0.tar.gz')},
+    'tempest-plugin-watcher': {
+        'type': 'url',
+        'location': ('$tarballs_base/watcher-tempest-plugin/'
+                     'watcher-tempest-plugin-1.0.0.tar.gz')},
+    'tempest-plugin-zaqar': {
+        'type': 'url',
+        'location': ('$tarballs_base/zaqar-tempest-plugin/'
+                     'zaqar_tempest_plugin-0.1.0.tar.gz')},
     'rally': {
         'type': 'url',
         'location': ('$tarballs_base/rally/'
-                     'rally-master.tar.gz')},
+                     'rally-1.2.1.tar.gz')},
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/sahara/'
-                     'sahara-8.0.2.tar.gz')},
+                     'sahara-9.0.0.tar.gz')},
     'searchlight-base': {
         'type': 'url',
         'location': ('$tarballs_base/searchlight/'
-                     'searchlight-4.0.0.tar.gz')},
+                     'searchlight-master.tar.gz')},
     'senlin-base': {
         'type': 'url',
         'location': ('$tarballs_base/senlin/'
-                     'senlin-5.0.1.tar.gz')},
+                     'senlin-6.0.0.tar.gz')},
     'solum-base': {
         'type': 'url',
         'location': ('$tarballs_base/solum/'
-                     'solum-5.5.1.tar.gz')},
+                     'solum-5.7.0.tar.gz')},
     'swift-base': {
         'type': 'url',
         'location': ('$tarballs_base/swift/'
-                     'swift-2.17.1.tar.gz')},
+                     'swift-2.19.0.tar.gz')},
     'tacker-base': {
         'type': 'url',
         'location': ('$tarballs_base/tacker/'
-                     'tacker-0.9.0.tar.gz')},
+                     'tacker-0.10.0.tar.gz')},
     'tacker-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-6.0.0.tar.gz')},
+                     'networking-sfc-7.0.0.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('$tarballs_base/tempest/'
-                     'tempest-18.0.0.tar.gz')},
+                     'tempest-19.0.0.tar.gz')},
     'tripleo-ui': {
         'type': 'url',
         'location': ('$tarballs_base/tripleo-ui/'
-                     'tripleo-ui-8.3.2.tar.gz')},
+                     'tripleo-ui-9.3.0.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/trove/'
-                     'trove-9.0.0.tar.gz')},
+                     'trove-10.0.0.tar.gz')},
     'vitrage-base': {
         'type': 'url',
         'location': ('$tarballs_base/vitrage/'
-                     'vitrage-2.3.0.tar.gz')},
+                     'vitrage-3.2.0.tar.gz')},
     'vmtp': {
         'type': 'url',
         'location': ('$tarballs_base/vmtp/'
-                     'vmtp-2.4.5.tar.gz')},
+                     'vmtp-master.tar.gz')},
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/watcher/'
-                     'python-watcher-1.8.0.tar.gz')},
+                     'python-watcher-1.12.0.tar.gz')},
     'zaqar': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar/'
-                     'zaqar-6.0.1.tar.gz')},
+                     'zaqar-7.0.0.tar.gz')},
     'zun-base': {
         'type': 'url',
         'location': ('$tarballs_base/zun/'
-                     'zun-1.0.1.tar.gz')}
+                     'zun-2.1.0.tar.gz')}
 }
 
 
@@ -1005,6 +1112,18 @@ USERS = {
     'hugetlbfs-user': {
         'uid': 42477,  # unused user, but we need the group for vhost socket
         'gid': 42477,
+    },
+    'logstash-user': {
+        'uid': 42478,
+        'gid': 42478,
+    },
+    'storm-user': {
+        'uid': 42479,
+        'gid': 42479,
+    },
+    'tempest-user': {
+        'uid': 42480,
+        'gid': 42480,
     }
 }
 
