@@ -14,14 +14,14 @@
 
 
 def debian_package_install(packages):
-    """Jinja utility method for building debian-based package install command
+    """Jinja utility method for building debian-based package install command.
 
     apt-get is not capable of installing .deb files from a URL and the
     template logic to construct a series of steps to install regular packages
     from apt repos as well as .deb files that need to be downloaded, manually
-    installed, and cleaned up is complicated. This method will contruct the
+    installed, and cleaned up is complicated. This method will construct the
     proper string required to install all packages in a way that's a bit
-    easier to follow
+    easier to follow.
 
     :param packages: a list of strings that are either packages to install
     from an apt repo, or URLs to .deb files
@@ -44,10 +44,12 @@ def debian_package_install(packages):
 
     # handle the apt-get install
     if reg_packages:
+        cmds.append('apt-get update')
         cmds.append('apt-get -y install --no-install-recommends {}'.format(
             ' '.join(reg_packages)
         ))
         cmds.append('apt-get clean')
+        cmds.append('rm -rf /var/lib/apt/lists/*')
 
     # handle URL packages
     for url in url_packages:
